=======
Credits
=======

Development Leads
-----------------

* James Byrne <jambyr@bas.ac.uk> (@jimcircadian)
* Tom Andersson <tomand@bas.ac.uk> (@tom-andersson)
* Scott Hosking <jask@bas.ac.uk> (@scotthosking)

Contributors
------------

* Oliver Strickson (@ots22)
* Ryan Chan (@rchan26)
